==> codelite_16.0.orig.tar.xz: codelite-16.0/docs/docs/settings/keyboard_shortcuts.md <==
# Customise keyboard shortcuts

---

1. From the menu bar, click on `Settings` &#8594; `Keyboard shortcuts`
2. Search the action that you want to assign / modify its keyboard shortcut

!!! note "TIP"
    The search box accepts partial words separated by spaces
    for example: to assign keyboard shortcut for toggling the main tool bar,
    typing the following in the search box: `bar too` is enough
    
3. Double click on the entry you want to modify and edit its
4. Click `OK` and you are all set

# Useful keyboard shortcuts
---

The table below lists a useful keyboard shortcuts:


 Keyboard Shortcut  | Description  
--------------------|--------------
 ++ctrl+shift+p++   | Goto anything. a convenient dialogue to replace the menu bar. All the menu bar actions are placed in this dialogue and can be activated without using the mosue 
 ++ctrl+shift+r++   | Open a resource. a resource can be file, class, function, variable etc
 ++ctrl+shift+o++   | Show current file class layout 
 ++ctrl+k++         | If a text is selected in the editor, use this shortcut to find and select another match in the editor (so you will end of with two selections). You can then edit these selections simultaneously
 ++ctrl+shift+k++   | Similar to the above, but select **all** occurances in the editor instead of doing it incrementally 
 ++ctrl+shift+f++   | Open the find in files dialogue 
 ++ctrl+m++         | Toggle all the panes 
 ++ctrl+f11++       | Toggle the minimal view 
 ++ctrl+"`"++       | Toggle the output pane 

!!! Tip
    There are many more useful keyboard shortcuts, you can view them all in the `Keyboard Shortcuts` dialog

==> codelite_18.1.0.orig.tar.xz: codelite-18.1.0/docs/docs/settings/keyboard_shortcuts.md <==
# Customise keyboard shortcuts

---

1. From the menu bar, click on `Settings` &#8594; `Keyboard shortcuts`
2. Search the action that you want to assign / modify its keyboard shortcut

!!! note "TIP"
    The search box accepts partial words separated by spaces
    for example: to assign keyboard shortcut for toggling the main tool bar,
    typing the following in the search box: `bar too` is enough
    
3. Double click on the entry you want to modify and edit its
4. Click `OK` and you are all set

# Useful keyboard shortcuts
---

The table below lists a useful keyboard shortcuts:


 Keyboard Shortcut  | Description  
--------------------|--------------
 ++ctrl+shift+p++   | Goto anything. a convenient dialogue to replace the menu bar. All the menu bar actions are placed in this dialogue and can be activated without using the mosue 
 ++ctrl+shift+r++   | Open a resource. a resource can be file, class, function, variable etc
 ++ctrl+shift+o++   | Show current file class layout 
 ++ctrl+k++         | If a text is selected in the editor, use this shortcut to find and select another match in the editor (so you will end of with two selections). You can then edit these selections simultaneously
 ++ctrl+shift+k++   | Similar to the above, but select **all** occurrences in the editor instead of doing it incrementally 
 ++ctrl+shift+f++   | Open the find in files dialogue 
 ++ctrl+m++         | Toggle all the panes 
 ++ctrl+f11++       | Toggle the minimal view 
 ++ctrl+"`"++       | Toggle the output pane 

!!! Tip
    There are many more useful keyboard shortcuts, you can view them all in the `Keyboard Shortcuts` dialog
